Header menu logo Falco.UnionRoutes

QueryParam<'T> Type

Marks a route field as coming from the query string instead of route parameters.

Use QueryParam<'T> option for optional query parameters that return None when missing.

Required query parameters (without option) return an error when missing.

Example

 type PostRoute =
     | Search of query: QueryParam<string>        // GET /posts/search?query=... (required)
     | List of page: QueryParam<int> option       // GET /posts?page=2 (optional, defaults to None)
type PostRoute = | Search of query: obj | List of page: obj
val query: Linq.QueryBuilder
Multiple items
val string: value: 'T -> string

--------------------
type string = System.String
Multiple items
module List from Microsoft.FSharp.Collections

--------------------
type List<'T> = | op_Nil | op_ColonColon of Head: 'T * Tail: 'T list interface IReadOnlyList<'T> interface IReadOnlyCollection<'T> interface IEnumerable interface IEnumerable<'T> member GetReverseIndex: rank: int * offset: int -> int member GetSlice: startIndex: int option * endIndex: int option -> 'T list static member Cons: head: 'T * tail: 'T list -> 'T list member Head: 'T with get member IsEmpty: bool with get member Item: index: int -> 'T with get ...
Multiple items
val int: value: 'T -> int (requires member op_Explicit)

--------------------
type int = int32

--------------------
type int<'Measure> = int
type 'T option = Option<'T>

Union cases

Union case Description

QueryParam 'T

Full Usage: QueryParam 'T

Parameters:
    Item : 'T

Item : 'T

Type something to start searching.