Header menu logo Falco.UnionRoutes

Route.MatchError Type

Error details when a URL fails to match any route.

Union cases

Union case Description

NoMatchingRoute

Full Usage: NoMatchingRoute

No route pattern matched the given method and URL.

ParameterError(routePath, paramName, value, expectedType)

Full Usage: ParameterError(routePath, paramName, value, expectedType)

Parameters:
    routePath : string
    paramName : string
    value : string
    expectedType : string

A route pattern matched, but a parameter value was invalid for its expected type.

routePath : string
paramName : string
value : string
expectedType : string

Instance members

Instance member Description

this.IsNoMatchingRoute

Full Usage: this.IsNoMatchingRoute

Returns: bool
Returns: bool

this.IsParameterError

Full Usage: this.IsParameterError

Returns: bool
Returns: bool

Type something to start searching.