Header menu logo Falco.UnionRoutes

RouteConstraint Type

ASP.NET Core parameterless route constraint kinds.

Type-based constraints (e.g., :guid, :int, :bool, :long) are derived implicitly from field types and do not appear in this enum.

Use with RouteAttribute or Extractor.constrainedParser to add constraints to route parameters.

Record fields

Record Field Description

Alpha

Full Usage: Alpha

Field type: RouteConstraint
Modifiers: static

Matches alphabetic characters only (a-z, A-Z).

Field type: RouteConstraint

File

Full Usage: File

Field type: RouteConstraint
Modifiers: static

Matches values that look like file names (contain a dot).

Field type: RouteConstraint

NonFile

Full Usage: NonFile

Field type: RouteConstraint
Modifiers: static

Matches values that do not look like file names.

Field type: RouteConstraint

Required

Full Usage: Required

Field type: RouteConstraint
Modifiers: static

Matches non-empty values.

Field type: RouteConstraint

Type something to start searching.