Route.MatchError Type
Error details when a URL fails to match any route.
Union cases
| Union case |
Description
|
Full Usage:
NoMatchingRoute
|
No route pattern matched the given method and URL. |
Full Usage:
ParameterError(routePath, paramName, value, expectedType)
Parameters:
string
paramName : string
value : string
expectedType : string
|
A route pattern matched, but a parameter value was invalid for its expected type.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsNoMatchingRoute
Returns: bool
|
|
Full Usage:
this.IsParameterError
Returns: bool
|
|
Falco.UnionRoutes